@@ -4,3 +4,6 @@
 # @Project : https://github.com/ykk648/cv2box
 from .cv_image import CVImage
 from .cv_queue import CVQueue
+from .cv_file import CVFile
+from .cv_video import CVVideo
+
